@@ -1,5 +1,5 @@
 # This file is a part of Arjuna
-# Copyright 2015-2020 Rahul Verma
+# Copyright 2015-2021 Rahul Verma
 
 # Website: www.RahulVerma.net
 
@@ -212,9 +212,13 @@ except ModuleNotFoundError as e:
             res_import_blocks.append(res_import_block.format(project=proj.name))
         res_import_blocks.append(res_import_block.format(project=self.ref_config.value(ArjunaOption.PROJECT_NAME)))
         contents = contents.format(res_import_block="".join(res_import_blocks))
-        f = open(get_proj_target_path("test/conftest.py"), "w")
-        f.write(contents)
-        f.close()
+
+        if os.path.exists(get_proj_target_path("test")):
+            f = open(get_proj_target_path("test/conftest.py"), "w")
+            f.write(contents)
+            f.close()
+        else:
+            raise Exception("No test directory found in project: {}. Check current directory or --project switch value.".format(self.ref_config.value(ArjunaOption.PROJECT_ROOT_DIR)))
 
         self.__create_dir_if_doesnot_exist(self.ref_config.value(ArjunaOption.REPORT_DIR))
         self.__create_dir_if_doesnot_exist(self.ref_config.value(ArjunaOption.REPORT_XML_DIR))
@@ -429,7 +433,7 @@ class Arjuna:
         return cls.__ARJ_COMMAND
 
     @classmethod
-    def init(cls, project_root_dir, cli_config=None, run_id=None, *, static_rid=False, linked_projects=[]):
+    def init(cls, project_root_dir, *, run_id=None, static_rid=False, linked_projects=[], arjuna_options={}, user_options={}):
         '''
             Returns reference test context which contains reference configuration.
             This reference test context merges central conf, project conf and central CLI options.
@@ -439,7 +443,8 @@ class Arjuna:
         cls.ARJUNA_SINGLETON = ArjunaSingleton()
         if linked_projects is None:
             linked_projects = list()
-        return cls.ARJUNA_SINGLETON.init(project_root_dir, cli_config, run_id, static_rid=static_rid, linked_projects=linked_projects)
+        from arjuna.configure.cli import CliArgsConfig
+        return cls.ARJUNA_SINGLETON.init(project_root_dir, CliArgsConfig({'ao': arjuna_options, 'uo': user_options}), run_id, static_rid=static_rid, linked_projects=linked_projects)
 
     @classmethod
     def get_logger(cls):
@@ -556,6 +561,7 @@ class Arjuna:
 
     @classmethod
     def register_test_meta_data(cls, qual_name, test_meta_data):
+        print(qual_name)
         cls.ARJUNA_SINGLETON.register_test_meta_data(qual_name, test_meta_data)
 
     @classmethod
